import finch.Finch;

/**
 * The main driver for Lab 3
 * <P>
 * <dt> <b>The responsibilities are: </b>
 * <dd>  Read a sequence of sensor samples from the Finch
 * <dd>  Find the min, median and max samples for some sensor and report the sample
 * <dd>  Repeat for different sensor streams
 * </dt>
 * 
 * <P>
 * 
 * @author Andrew H. Fagg and Steven Ness
 */

public class sensorDriver {
	
	/** Total number of samples to take */
	public static final int numSamples = 100;
	
	/** 
	 * Interval between samples (note that there is also other overhead that extends
	 * this delay)
	 */
	public static final int sampleInterval = 50; // In ms
	
	/**
	 * Sort an array of Comparable2 objects
	 * 
	 *  Adopted from Listing 11.10 from "Introduction to Java Programming".
	 *  The key difference is that we are now calling the compareTo2(), which
	 *  accepts as a parameter both an object to be compared and a variable that
	 *  acts as a key.
	 *  
	 * @param list				A valid list of objects to be sorted
	 * @param var				The key that indicates which variable to sort on
	 * 
	 * <dt><b>Conditions:</b>
     * <dd>PRE  -         The list must already be instantiated
     * <dd>POST -         The list is reorded such that the smallest value is at index 0
     *                        and the largest value is at index list.length-1
	 */
	
	public static void sort(Comparable2 list[], VariableType var)
	{
		Comparable2 currentMax;
		int currentMaxIndex;
		
		// Loop from bottom to top
		for(int i = list.length - 1; i >= 1; --i)
		{
			// Find the maximum in the list[0 .. i]
			currentMax = list[i];
			currentMaxIndex = i;
			for(int j = i - 1; j >= 0; --j)
			{
				if(currentMax.compareTo2(list[j], var) < 0)
				{
					currentMax = list[j];
					currentMaxIndex = j;
				}
			}
			
			// Swap list[i] with list[currentMaxIndex] if they are different
			if(currentMaxIndex != i)
			{
				list[currentMaxIndex] = list[i];
				list[i] = currentMax;
			}
		}
	}
	
	/**
	 * For the given sensor channel (as indicated by var), display the entire sensor 
	 *   sample for the minimum, median and maximum channel values
	 *   
	 * @param log	An valid array of Finch sensor samples
	 * @param var	The sensor channel on which to organize the list
	 * 
	 */
	public static void displayStats(FinchSensor[] log, SensorType var)
	{
		// Sort this channel by a particular variable: smallest to largest
		sort(log, var);
		
		// Name of the variable
		System.out.println("Variable: " + var);
		
		// The minimum sample
		System.out.println("Min:    " + log[0]);
		
		// The median sample
		System.out.println("Median: " + log[log.length/2]);
		
		// The max sample
		System.out.println("Max:    " + log[log.length - 1]);
		
		System.out.println("");
	}
	
	/**
	 * Display the sequence of sensor samples in the given array
	 * 
	 * @param sensors	An array of sensor samples
	 */
	
	public static void displaySensors(FinchSensor sensors[])
	{
		for(int i = 0; i < sensors.length; ++i)
		{
			System.out.println(sensors[i]);
		}
	}
	
	/**
	 * Read a sequence of samples from the Finch sensors
	 * 
	 * @param 	myFinch		Reference to the finch object
	 * @return		An array of samples
	 */
	public static FinchSensor[] ReadSensors(Finch myFinch)
	{
		FinchSensor[] samples = new FinchSensor[numSamples];
		
		// Loop over the set of samples
		for(int i = 0; i < numSamples; ++i){
			// Grab the sensor values
			int light[] = myFinch.getLightSensors();
			double acceleration[] = myFinch.getAccelerations();
			double temperature = myFinch.getTemperature();
			boolean obstacle[] = myFinch.getObstacleSensors();
			
			// Create a new FinchSensor
			samples[i] = new FinchSensor(light, acceleration, obstacle, temperature);
			
			// Delay before the next sample
			myFinch.sleep(sampleInterval);
			
		}
		return(samples);
	}
	
	/**
	 * The main method
	 * 
	 * @param 	args	Program arguments
	 */
	public static void main(String[] args)
	{
		// Connect to the Finch
		Finch myFinch = new Finch();
		
		// Log a set of samples
		myFinch.setLED(255,0,0); 
		FinchSensor log[] = ReadSensors(myFinch);
		myFinch.setLED(0,0,255); 
	
		// Show the samples in order
		System.out.println("Original Log:");
		displaySensors(log);
		
		// Show the samples with the min,median,max values of Z component of acceleration
		displayStats(log, SensorType.ACCEL_Z);
		
		// Show the samples with the min,median,max values of temperature
		displayStats(log, SensorType.TEMPERATURE);
		
		// Show the samples with the min,median,max values of the left light sensor
		displayStats(log, SensorType.LIGHT_LEFT);
		
		// Clean up and quit
		myFinch.stopWheels();
		myFinch.quit();
	}
}